==> jc-1.4.0.tar.gz: java/awt/Container__24AccessibleAWTContainer__24AccessibleContainerHandler.h <==
// public class java.awt.Container$AccessibleAWTContainer$AccessibleContainerHandler

// class file dependencies
// @dep_class d9ef3420ad44fce1 java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_
#define _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_

// Forward structure declarations
struct _jc_java_awt_Container__24AccessibleAWTContainer$object;
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object;

typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype;

// Constructors
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$_init$c5204d9a9b2a5e57(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *);

// Virtual methods
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *);
};

// Vtable
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
};

// Vtype
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs {
	struct _jc_java_awt_Container__24AccessibleAWTContainer$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs {
    _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
};

// Object instance structure
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object {
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype	*vtype;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$class_object;

#endif	/* _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_ */

==> jc-1.4.6.tar.gz: java/awt/Container__24AccessibleAWTContainer__24AccessibleContainerHandler.h <==
// public class java.awt.Container$AccessibleAWTContainer$AccessibleContainerHandler

// class file dependencies
// @dep_class d9ef3420ad44fce1 java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_
#define _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_

// Forward structure declarations
struct _jc_java_awt_Container__24AccessibleAWTContainer$object;
struct _jc_java_awt_event_ContainerEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs;
typedef struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object;

typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable;
typedef const struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype;

// Constructors
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$_init$c5204d9a9b2a5e57(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_Container__24AccessibleAWTContainer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$componentAdded$c1a226b52e818d0c(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method$componentRemoved$0b1853b514a86e99(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method_info$componentAdded$c1a226b52e818d0c;
extern _jc_method _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$method_info$componentRemoved$0b1853b514a86e99;

// Virtual methods structure
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods {
	void	(*componentAdded$c1a226b52e818d0c)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
	void	(*componentRemoved$0b1853b514a86e99)(_jc_env *, struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object *, struct _jc_java_awt_event_ContainerEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vmethods	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
};

// Vtype
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs {
	struct _jc_java_awt_Container__24AccessibleAWTContainer$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs {
    _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_refs	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler;
};

// Object instance structure
struct _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$object {
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype	*vtype;
	_jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$vtype _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler$class_object;

#endif	/* _JC_java_awt_Container__24AccessibleAWTContainer__24AccessibleContainerHandler_H_ */
